#include <QtGui>
#include <math.h>
#include "scene3D.h"

Scene3D::Scene3D(QWidget* parent) : QGLWidget(parent)
{
    xRot=-90; yRot=0; zRot=0; zTra=0; nSca=1;
    controlClear = false;
    isPaused = false;
}

void Scene3D::mousePressEvent(QMouseEvent* pe)
{
    mousePosition = pe->pos();
    leftButtonPressed = true;
    //isPaused = !isPaused;
    updateGL();
}

void Scene3D::mouseDoubleClickEvent(QMouseEvent* pe)
{
    isPaused = !isPaused;
}

void Scene3D::mouseGrabber()
{

}

void Scene3D::mouseReleaseEvent(QMouseEvent* pe)
{

}

void Scene3D::mouseMoveEvent(QMouseEvent* pe)
{
    if(pe->buttons())
    {
        xRot += 180/nSca*(GLfloat)(pe->y()-mousePosition.y())/height();
        zRot += 180/nSca*(GLfloat)(pe->x()-mousePosition.x())/width();
    }
    mousePosition = pe->pos();
    updateGL();
}

void Scene3D::wheelEvent(QWheelEvent* pe)
{
    if ((pe->delta()) < 0)
        scale_plus();
    else
        if ((pe->delta()) > 0)
            scale_minus();
    updateGL();
}

void Scene3D::keyPressEvent(QKeyEvent* pe)
{
    switch (pe->key())
    {
    case Qt::Key_Plus:
        scale_plus();
        break;

    case Qt::Key_Equal:
        scale_plus();
        break;

    case Qt::Key_Minus:
        scale_minus();
        break;

    case Qt::Key_Up:
        rotate_up();
        break;

    case Qt::Key_Down:
        rotate_down();
        break;

    case Qt::Key_Left:
        rotate_left();
        break;

    case Qt::Key_Right:
        rotate_right();
        break;

    case Qt::Key_Z:
        translate_down();
        break;

    case Qt::Key_X:
        translate_up();
        break;

    case Qt::Key_Space:
        defaultScene();
        break;

    case Qt::Key_Escape:
        this->close();
        break;
    }
    if(pe->key() == Qt::Key_Up)
        nSca *= 2;
    updateGL();
}

void Scene3D::scale_plus()
{
    nSca = nSca*1.1;
}

void Scene3D::scale_minus()
{
    nSca = nSca/1.1;
}

void Scene3D::rotate_up()
{
    xRot += 1.0;
}

void Scene3D::rotate_down()
{
    xRot -= 1.0;
}

void Scene3D::rotate_left()
{
    zRot += 1.0;
}

void Scene3D::rotate_right()
{
    zRot -= 1.0;
}

void Scene3D::translate_down()
{
    zTra -= 0.05;
}

void Scene3D::translate_up()
{
    zTra += 0.05;
}

void Scene3D::defaultScene()
{
    xRot=-90; yRot=0; zRot=0; zTra=0; nSca=1;
}

